<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar_JO">
<context>
    <name>QObject</name>
    <message>
        <location filename="../../radialMap/map.cpp" line="108"/>
        <source>%1 files</source>
        <translation>ملفات %1</translation>
    </message>
    <message numerus="yes">
        <location filename="../../radialMap/map.cpp" line="204"/>
        <source>%n file(s), with an average size of %1</source>
        <comment>file</comment>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RadialMap::Widget</name>
    <message numerus="yes">
        <location filename="../../radialMap/widgetEvents.cpp" line="194"/>
        <location filename="../../radialMap/widgetEvents.cpp" line="196"/>
        <source> into %n file(s)</source>
        <comment>file</comment>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Themes</name>
    <message>
        <location filename="../../interface.cpp" line="293"/>
        <location filename="../../interface.cpp" line="314"/>
        <source>Buy the Ultimate version to fund development</source>
        <translation>شراء النسخة النهائية لتمويل التنمية</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="293"/>
        <location filename="../../interface.cpp" line="314"/>
        <source>Register your key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="525"/>
        <source>File %1/%2, size: %3/%4</source>
        <translation>الملف %1/%2 ، الحجم: %3/%4</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="832"/>
        <source>Copy list</source>
        <translation>قائمة النسخ</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="834"/>
        <source>Move list</source>
        <translation>قائمة التحريك</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1335"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>لا تغلق إذا تم العثور على أخطاء</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1336"/>
        <source>Never close</source>
        <translation>لا تغلق</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1337"/>
        <source>Always close</source>
        <translation>إغلاق دائما</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1339"/>
        <source>File Name, 0KB</source>
        <translation>اسم الملف ، 0KB</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1549"/>
        <location filename="../../interface.cpp" line="1561"/>
        <location filename="../../interface.cpp" line="1573"/>
        <source>Select a color</source>
        <translation>تحديد لون</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1661"/>
        <location filename="../../interface.cpp" line="1672"/>
        <location filename="../../interface.cpp" line="1681"/>
        <source>%1 %2% of %3 into %4 files</source>
        <translation>%1 %2% من %3 إلى ملفات %4</translation>
    </message>
</context>
<context>
    <name>ThemesFactory</name>
    <message>
        <location filename="../../ThemesFactory.cpp" line="320"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>عدم الإغلاق في حاله العثور على أخطاء</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="321"/>
        <source>Never close</source>
        <translation>لا تغلق أبدا</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="322"/>
        <source>Always close</source>
        <translation>إغلاق دائما</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="518"/>
        <location filename="../../ThemesFactory.cpp" line="533"/>
        <location filename="../../ThemesFactory.cpp" line="548"/>
        <source>Select a color</source>
        <translation>تحديد لون</translation>
    </message>
</context>
<context>
    <name>interfaceCopy</name>
    <message>
        <location filename="../../interface.ui" line="420"/>
        <source>From:</source>
        <translation>من:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="301"/>
        <source>&amp;More</source>
        <translation>&amp;اكثر </translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="321"/>
        <source>&amp;Pause</source>
        <translation>&amp;مهلة</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="482"/>
        <source>&amp;Skip</source>
        <translation>&amp;تخطي</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="493"/>
        <source>&amp;Cancel</source>
        <translation>&amp;الغاء الامر</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="389"/>
        <source>Close on transfer completion</source>
        <translation>إغلاق عند إتمام النقل</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="232"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="252"/>
        <source>100MB+</source>
        <translation>100MB+</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="527"/>
        <source>Limit copy speed to:</source>
        <translation>الحد من سرعه النسخ إلى:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="570"/>
        <source>Transfer list</source>
        <translation>قائمه النقل</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="593"/>
        <source>Move the selected items to the top</source>
        <translation>تحريك المواد المحددة إلى الأعلى</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="619"/>
        <source>Move up the selected items</source>
        <translation>تحريك المواد المحددة لاعلى</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="645"/>
        <source>Move down the selected items</source>
        <translation>تحريك المواد المحددة لأسفل</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="671"/>
        <source>Move the selected items to the bottom</source>
        <translation>تحريك العناصر المحددة إلى الأسفل</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="697"/>
        <source>Add file/folder</source>
        <translation>أضافه ملف/مجلد</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="726"/>
        <source>Delete the selected items</source>
        <translation>حذف المواد المحددة</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="752"/>
        <source>Search</source>
        <translation>بحث</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="781"/>
        <source>Export the transfer list</source>
        <translation>تصدير قائمه النقل</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="807"/>
        <source>Import the transfer list</source>
        <translation>استيراد قائمه النقل</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="862"/>
        <source>Previous</source>
        <translation>السابق</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="869"/>
        <source>Next</source>
        <translation>التالي</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="904"/>
        <location filename="../../interface.ui" line="973"/>
        <source>Error</source>
        <translation>خطا</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="924"/>
        <source>Export the errors into transfer list</source>
        <translation>تصدير الأخطاء إلى قائمه النقل</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="963"/>
        <source>Source</source>
        <translation>المصدر</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="968"/>
        <source>Destination</source>
        <translation>الوجهه</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="982"/>
        <source>Interface</source>
        <translation>الواجهه</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="1028"/>
        <source>Add file</source>
        <translation>اضافة ملف</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="1037"/>
        <source>Add folder</source>
        <translation>اضافة مجلد</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="1046"/>
        <source>Move file(s)</source>
        <translation>نقل الملفات</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="1055"/>
        <source>Move folder</source>
        <translation>نقل المجلد</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="1064"/>
        <source>Copy file(s)</source>
        <translation>نسخ الملفات</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="1073"/>
        <source>Copy folder</source>
        <translation>نسخ المجلد</translation>
    </message>
</context>
<context>
    <name>themesOptions</name>
    <message>
        <location filename="../../themesOptions.ui" line="293"/>
        <source>Show dual progression</source>
        <translation>إظهار التقدم المزدوج</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="245"/>
        <source>Show speed as main information</source>
        <translation>إظهار السرعة كمعلومات رئيسيه</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="44"/>
        <source>Use</source>
        <translation>استخدام</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="110"/>
        <source>Start with the &quot;more button&quot; pushed</source>
        <translation>تبدا مع  &quot;أكثر زر&quot; دفعت</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="57"/>
        <source>Minimize on close to systray</source>
        <translation>تصغير بالقرب من درج النظام</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="80"/>
        <source>At the end of the copy</source>
        <translation>في نهاية النسخ</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="70"/>
        <location filename="../../themesOptions.ui" line="87"/>
        <source>Limit copy speed to</source>
        <translation>الحد من سرعه النسخ إلى</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="97"/>
        <source> KB/s</source>
        <translation>KB/s</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="117"/>
        <source>Start minimized</source>
        <translation>بدء التصغير</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="144"/>
        <source>Position at start</source>
        <translation>الموضع في البداية</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="204"/>
        <source>Dark UI</source>
        <translation>واجهه مستخدم داكنه</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="212"/>
        <source>Default</source>
        <translation>افتراضي</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="217"/>
        <source>Save as previous</source>
        <translation>حفظ كسابق</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="222"/>
        <source>At Center</source>
        <translation>في الوسط</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="239"/>
        <source>Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="277"/>
        <source>Display</source>
        <translation>عرض</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="283"/>
        <source>Speed with progress bar</source>
        <translation>السرعة مع شريط التقدم</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="313"/>
        <source>Progression color</source>
        <translation>تدرج اللون</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="332"/>
        <source>Click to edit the color</source>
        <translation>انقر لتحرير اللون</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="303"/>
        <source>Show progression in the title</source>
        <translation>إظهار التقدم في العنوان</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="137"/>
        <source>Always on top</source>
        <translation>دائما في القمه</translation>
    </message>
</context>
</TS>
